/********************************************************************************
** Form generated from reading UI file 'searchtoolbar.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHTOOLBAR_H
#define UI_SEARCHTOOLBAR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SearchToolBar
{
public:
    QHBoxLayout *hboxLayout;
    QToolButton *hideButton;
    QLabel *label;
    QLineEdit *searchTextEdit;
    QToolButton *nextButton;
    QToolButton *previousButton;
    QToolButton *matchCaseCheckButton;

    void setupUi(QWidget *SearchToolBar)
    {
        if (SearchToolBar->objectName().isEmpty())
            SearchToolBar->setObjectName("SearchToolBar");
        SearchToolBar->resize(582, 35);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SearchToolBar->sizePolicy().hasHeightForWidth());
        SearchToolBar->setSizePolicy(sizePolicy);
        hboxLayout = new QHBoxLayout(SearchToolBar);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, -1, 0, 0);
        hideButton = new QToolButton(SearchToolBar);
        hideButton->setObjectName("hideButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-close")));
        hideButton->setIcon(icon);
        hideButton->setAutoRaise(true);

        hboxLayout->addWidget(hideButton);

        label = new QLabel(SearchToolBar);
        label->setObjectName("label");

        hboxLayout->addWidget(label);

        searchTextEdit = new QLineEdit(SearchToolBar);
        searchTextEdit->setObjectName("searchTextEdit");
        searchTextEdit->setClearButtonEnabled(true);

        hboxLayout->addWidget(searchTextEdit);

        nextButton = new QToolButton(SearchToolBar);
        nextButton->setObjectName("nextButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("go-down-search")));
        nextButton->setIcon(icon1);
        nextButton->setAutoRaise(true);

        hboxLayout->addWidget(nextButton);

        previousButton = new QToolButton(SearchToolBar);
        previousButton->setObjectName("previousButton");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("go-up-search")));
        previousButton->setIcon(icon2);
        previousButton->setAutoRaise(true);

        hboxLayout->addWidget(previousButton);

        matchCaseCheckButton = new QToolButton(SearchToolBar);
        matchCaseCheckButton->setObjectName("matchCaseCheckButton");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("format-text-superscript")));
        matchCaseCheckButton->setIcon(icon3);
        matchCaseCheckButton->setCheckable(true);
        matchCaseCheckButton->setAutoRaise(true);

        hboxLayout->addWidget(matchCaseCheckButton);

#if QT_CONFIG(shortcut)
        label->setBuddy(searchTextEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SearchToolBar);

        QMetaObject::connectSlotsByName(SearchToolBar);
    } // setupUi

    void retranslateUi(QWidget *SearchToolBar)
    {
        label->setText(tr2i18n("Find:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        nextButton->setToolTip(tr2i18n("Jump to next match", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        previousButton->setToolTip(tr2i18n("Jump to previous match", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        matchCaseCheckButton->setToolTip(tr2i18n("Match case sensitive", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        (void)SearchToolBar;
    } // retranslateUi

};

namespace Ui {
    class SearchToolBar: public Ui_SearchToolBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHTOOLBAR_H

